@@ -467,7 +467,7 @@ class Commuter:
         """
 
         return self.select_one(
-            cmd=f'SELECT SUM(numbackends) FROM pg_stat_database',
+            cmd='SELECT SUM(numbackends) FROM pg_stat_database',
             default=0)
 
     @fix_schema
@@ -787,6 +787,8 @@ class Commuter:
                 if row.data_type in ['smallint', 'integer', 'bigint']:
                     if data[column].dtype == np.float:
                         data[column] = data[column].round().astype('Int64')
+                elif row.data_type in ['text']:
+                    data[column] = data[column].str.replace(',', '')
 
         return data[columns]
 
